
@import "@synerty/peek-plugin-base-js/src/styles/_variables";
@import "src/variables";

.task-form-card {
    margin: $general_margin_2;

    .notification-methods {
        margin: $general_margin_2 0;

        h4 {
            margin-bottom: $general_margin_1;
            font-size: $general_font_size_3;
        }
    }

    .actions-section {
        margin: $general_margin_2 0;

        .add-action-button {
            margin-bottom: $general_margin_2;
        }

        .action-item {
            padding: $general_padding_2;
            margin-bottom: $general_margin_2;
            background-color: $grey-color-translucent;
            border-radius: $border-radius;

            h4 {
                margin-bottom: $general_margin_1;
                font-size: $general_font_size_3;
            }
        }
    }

    .button-container {
        display: flex;
        justify-content: flex-end;
        margin-top: $general_margin_2;
    }
}

nz-form-item {
    margin-bottom: $general_margin_1;
}

nz-date-picker {
    width: 100%;
}

nz-select {
    width: 100%;
}