
@import "@synerty/peek-plugin-base-js/src/styles/_variables";
@import "src/variables";

.activity-form-card {
    margin: $general_margin_2;

    .button-container {
        display: flex;
        justify-content: flex-end;
        margin-top: $general_margin_2;
    }

    :host {
        .ant-form-item {
            margin-bottom: $general_margin_1;
        }
    }
}

nz-form-item {
    margin-bottom: $general_margin_1;
}

nz-date-picker {
    width: 100%;
}