
@import "@synerty/peek-plugin-base-js/src/styles/_variables";
@import "src/variables";

.settings-card {
    margin: $general_margin_2;

    .button-container {
        display: flex;
        justify-content: flex-end;
        gap: $general_padding_1;
        margin-top: $general_margin_2;
    }
}