
@import "@synerty/peek-plugin-base-js/src/styles/_variables";
@import "src/variables";

.task-list-container {
    display: flex;
    flex-direction: column;
    padding: $general_padding_2;

    .user-form {
        margin-bottom: $general_margin_2;
    }
}